# -*- coding: utf-8 -*-
#    Copyright 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import os
import gtk

import Conf, func, i18n

_ = i18n.gettext()

class Label (gtk.HBox) :

	LABELNAME = ""
	LABELNAME_SHORT = ""
	STATE = None
	Child = None

	EVENTBOX = None

	WITHOUT_CLOSEBUTTON = False

	def __init__ (self, **kwargs) :

		gtk.HBox.__init__(self, False, 2)

		if kwargs.has_key("state") :
			self.STATE = kwargs["state"]

		if kwargs.has_key("labelname") :
			self.LABELNAME = kwargs["labelname"]

		if kwargs.has_key("labelname_short") :
			self.LABELNAME_SHORT = kwargs["labelname_short"]

		if kwargs.has_key("without_closebutton") :
			if kwargs["without_closebutton"] :
				self.WITHOUT_CLOSEBUTTON = True

		if not self.LABELNAME_SHORT :
			self.LABELNAME_SHORT = self.LABELNAME

		self.make()
		self.show()

	def make (self) : pass

	def registerChild (self, child) :
		self.Child = child

class TabWithClose (Label) :

	def __init__ (self, **kwargs) :

		if kwargs.has_key("filename") :
			self.LABELNAME = kwargs["filename"]

		Label.__init__(self, **kwargs)

	def make (self, labelname=None, labelname_short=None) :
		if labelname : self.LABELNAME = labelname
		if labelname_short : self.LABELNAME_SHORT = labelname_short

		self.Label = gtk.Label(self.LABELNAME_SHORT)
		self.Label.set_selectable(False)
		self.Label.set_justify(gtk.JUSTIFY_CENTER)
		self.Label.set_property("selectable", False)
		self.Label.show()

		self.EVENTBOX = gtk.EventBox()
		self.EVENTBOX.add(self.Label)
		self.EVENTBOX.show()

		# make close button
		if not self.WITHOUT_CLOSEBUTTON :
			self.Button = gtk.ToolButton(gtk.STOCK_CLOSE)
			self.Button.show()
			self.Button.connect("clicked", self.on_tab_close)

		# connect event with method.
		self.EVENTBOX.connect("event", self.on_tab_label)

		# add close button and label in HBOX
		self.pack_start(self.EVENTBOX, False)

		self.set_tooltip()

		if not self.WITHOUT_CLOSEBUTTON :
			self.pack_end(self.Button, False)

	def on_tab_label (self, parm1, parm2) :
		__type = parm2.type

		if __type is gtk.gdk.ENTER_NOTIFY :
			if self.LABELNAME == "None" : return

			self.STATE.DATA["statusbar"].set_label( \
				" %s" % self.LABELNAME)
		elif __type is gtk.gdk.LEAVE_NOTIFY :
			self.STATE.DATA["statusbar"].clean()
		else :
			pass

	def on_tab_close (self, widget) :
		self.Child.exit()
		self.STATE.DATA["statusbar"].clean()

	def get_label (self) :
		return self.LABELNAME

	def set_label (self, labelname, labelname_short=None) :
		self.LABELNAME = labelname
		if labelname_short :
			self.LABELNAME_SHORT = labelname_short
		else :
			self.LABELNAME_SHORT = self.LABELNAME

		__labelname = func.get_labelname(self.LABELNAME_SHORT)

		self.Label.set_label(__labelname)

		self.set_tooltip()

	def set_tooltip (self) :
		# add toolip in event box
		__tooltip = gtk.Tooltips()
		__tooltip.set_tip(self.EVENTBOX, self.LABELNAME)
		__tooltip.enable()

class TabWithCloseForVim (TabWithClose) :

	def __init__ (self, **kwargs) :

		gtk.HBox.__init__(self, False, 2)

		if kwargs.has_key("filename") :
			self.LABELNAME = kwargs["filename"]

		if self.LABELNAME.strip() :
			self.LABELNAME_SHORT = os.path.basename(self.LABELNAME)

		if kwargs.has_key("state") :
			self.STATE = kwargs["state"]

		self.make(self.LABELNAME, self.LABELNAME_SHORT)
		self.show()

	def set_label (self, labelname) :
		self.LABELNAME = labelname
		self.LABELNAME_SHORT = os.path.basename(labelname)

		self.set_tooltip()

	def get_label (self) :
		return self.LABELNAME

class Statusbar :

	LABEL = None

	INSTANCE_STATUSBAR = None

	def __init__ (self, instanceOfStatusbar, context="default") :

		if not isinstance(instanceOfStatusbar, gtk.Statusbar) :
			raise ValueError, \
				_("instanceOfStatusbar must be gtk.Statusbar")
		else :
			self.INSTANCE_STATUSBAR = instanceOfStatusbar

		# get label instance
		try :
			self.LABEL = instanceOfStatusbar.get_children()[0].get_children()[0]
		except IndexError :
			raise ValueError, "It's not correct gtk.statusbar widget"

		self.LABEL.set_property("use-markup", True)
		self.LABEL.set_property("selectable", True)

	def clean (self) :
		self.LABEL.set_label( \
			("%s VEE " % _("VEE")) + _("To find more features, See the Contents.") \
		)

	def set_label (self, text) :
		self.LABEL.set_label(text)

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "Label.py"


